| Title: | R-Friendly Threading in C++ |
|---|---|
| Description: | Provides a C++11-style thread class and thread pool that can safely be interrupted from R. See Nagler (2021) <doi:10.18637/jss.v097.c01>. |
| Authors: | Thomas Nagler [aut, cre] (ORCID: <https://orcid.org/0000-0003-1855-0046>) |
| Maintainer: | Thomas Nagler <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 2.3.0 |
| Built: | 2026-05-17 08:12:00 UTC |
| Source: | https://github.com/tnagler/rcppthread |
Detects the number of (logical) CPU cores.
detectCores()detectCores()
To be used in Makevars on Linux and OSX. Returns a string with
linker flags for pthread and libatomic, if available.
LdFlags()LdFlags()
Use as ‘PKG_LIBS = $(R_HOME)/bin/Rscript -e ’RcppThread::LdFlags()'.
Provides a C++11-style thread class and thread pool that can safely be interrupted from R.
Maintainer: Thomas Nagler [email protected] (ORCID)
Nagler, T. (2021). "R-Friendly Multi-Threading in C++." Journal of Statistical Software, Code Snippets, 97(1), 1-18. doi:10.18637/jss.v097.c01.
Useful links: